import * as connectors from '../connectors/connectors';
import * as authentifiers from '../connectors/authentifiers';

const GroupResolvers = {
    // @rights viewer(obj.uid)
    Group: {
        __resolveType: async (obj) => {
            switch (obj.type) {
            case "simple":
                return "SimpleGroup";
            case "meta":
                return "MetaGroup";
            }
        }
    },

    // @rights viewer(obj.uid)
    SimpleGroup: {
        async admins(obj, args, context) {
            let user = await authentifiers.member(context.user, obj.uid);
            return await user.ldap_access.listMembers(context.user, obj.uid);
        },

        async members(obj, args, context) {
            let user = await authentifiers.member(context.user, obj.uid);
            const res: String[] = await user.ldap_access.listMembers(context.user, obj.uid);
            return res.map(x => {
                return {uid: x};
            });
        },

        async likers(obj, args, context) {
            return connectors.utilisateur.listMembers(context.user, obj.uid);
        },

        async privatePosts(obj, args, context) {
            let user = await authentifiers.member(context.user, obj.uid);
            return user && connectors.receivedPrivatePosts(user, obj.uid);
        },

        async questions(obj, args, context) {
            let user = await authentifiers.member(context.user, obj.uid);
            return user && connectors.receivedQuestions(user, obj.uid);
        },

        async answers(obj, args, context) {
            let user = await authentifiers.member(context.user, obj.uid);
            return user && connectors.receivedAnswers(user, obj.uid);
        }
    },

    // @rights viewer(obj.uid)
    MetaGroup: {
        async members(obj, args, context) {
        },

        async privatePosts(obj, args, context) {
            let user = await authentifiers.member(context.user, obj.uid);
            return user && connectors.receivedPrivatePosts(user, obj.uid);
        },

        async questions(obj, args, context) {
            let user = await authentifiers.member(context.user, obj.uid);
            return user && connectors.receivedQuestions(user, obj.uid);
        },

        async answers(obj, args, context) {
            let user = await authentifiers.member(context.user, obj.uid);
            return user && connectors.receivedAnswers(user, obj.uid);
        }
    }
};

export default GroupResolvers;